@@ -19,6 +19,10 @@ static const gchar developers[] =
     "Martin Hasoň\n"
     "Philipp Rahe\n"
     "Matthew Caldwell\n"
+    "Андрей Груздев\n"
+    "Даниил Браташов\n"
+    "François Bianco\n"
+    "Luke Somers\n"
 ;
 static const gchar translators[] =
     "David Nečas (Yeti)\n"
