@@ -20,6 +20,9 @@ GType gwy_visibility_reset_type_get_type(void) G_GNUC_CONST;
 GType gwy_menu_sens_flags_get_type(void) G_GNUC_CONST;
 #define GWY_TYPE_MENU_SENS_FLAGS (gwy_menu_sens_flags_get_type())
 
+GType gwy_text_header_error_get_type(void) G_GNUC_CONST;
+#define GWY_TYPE_TEXT_HEADER_ERROR (gwy_text_header_error_get_type())
+
 GType gwy_plain_tool_changed_get_type(void) G_GNUC_CONST;
 #define GWY_TYPE_PLAIN_TOOL_CHANGED (gwy_plain_tool_changed_get_type())
 
