@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyddion.c 9309 2009-06-24 14:00:06Z yeti-dn $
+ *  @(#) $Id: gwyddion.c 10264 2009-10-19 20:40:47Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -34,6 +34,7 @@
 #include <app/gwyapp.h>
 #include "gwyappinternal.h"
 #include "gwyddion.h"
+#include "mac_integration.h"
 
 #ifdef G_OS_WIN32
 #define LOG_TO_FILE_DEFAULT TRUE
@@ -92,6 +93,10 @@ main(int argc, char *argv[])
 
     timer = g_timer_new();
     gwy_app_check_version();
+
+    gwy_osx_init_handler(&argc);
+    gwy_osx_set_locale();
+
     process_preinit_options(&argc, &argv, &app_options);
     gwy_debug_objects_enable(app_options.debug_objects);
     /* TODO: handle failure */
@@ -104,7 +109,7 @@ main(int argc, char *argv[])
     setup_locale_from_win32_registry();
     gtk_init(&argc, &argv);
     debug_time(timer, "gtk_init()");
-    gwy_app_do_remote(app_options.remote, argc - 1, argv + 1);
+    gwy_remote_do(app_options.remote, argc - 1, argv + 1);
     gwy_app_init(&argc, &argv);
     debug_time(timer, "gwy_app_init()");
 
@@ -184,8 +189,12 @@ main(int argc, char *argv[])
     g_timer_destroy(timer);
     debug_time(NULL, "STARTUP");
 
+    gwy_osx_open_files();
+
     gtk_main();
 
+    gwy_osx_remove_handler();
+
     timer = g_timer_new();
     /* TODO: handle failure */
     if (settings_ok || !has_settings)
@@ -436,10 +445,19 @@ setup_locale_from_win32_registry(void)
 
     if (RegOpenKeyEx(HKEY_CURRENT_USER, TEXT("Software\\Gwyddion\\1.0"),
                      0, KEY_READ, &reg_key) == ERROR_SUCCESS) {
-        RegQueryValueEx(reg_key, TEXT("gwy_locale"), NULL, NULL, locale, &size);
-        g_setenv("LANG", locale, TRUE);
+        if (RegQueryValueEx(reg_key, TEXT("gwy_locale"), NULL, NULL, locale, &size) == ERROR_SUCCESS){
+            g_setenv("LANG", locale, TRUE);
+            RegCloseKey(reg_key);
+            return;
+        }
         RegCloseKey(reg_key);
-   }
+    }
+    if (RegOpenKeyEx(HKEY_LOCAL_MACHINE, TEXT("Software\\Gwyddion\\1.0"),
+                     0, KEY_READ, &reg_key) == ERROR_SUCCESS) {
+        if (RegQueryValueEx(reg_key, TEXT("gwy_locale"), NULL, NULL, locale, &size) == ERROR_SUCCESS)
+            g_setenv("LANG", locale, TRUE);
+        RegCloseKey(reg_key);
+    }
 #endif
 }
 
