@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyserializable.c 8874 2008-12-28 12:16:22Z yeti-dn $
+ *  @(#) $Id: gwyserializable.c 10097 2009-09-03 08:47:14Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -1043,11 +1043,14 @@ gwy_serialize_skip_type(const guchar *buffer,
                         gsize *position,
                         guchar ctype)
 {
-    static const gchar *too_short_msg =
-        "Truncated or corrupted buffer, need %" G_GSIZE_FORMAT " bytes "
-        "to skip <%c>, but only %" G_GSIZE_FORMAT " bytes remain.";
-    static const gchar *no_string_msg =
-        "Expected a string, trying to skip to end of [sub]buffer.";
+/* XXX: Must use #defines that have no scope and are not visible in debugger
+ * instead of const char buffers because Mandriva's idiotic enforcement of
+ * -Werror=format-security. */
+#define too_short_msg \
+        "Truncated or corrupted buffer, need %" G_GSIZE_FORMAT " bytes " \
+        "to skip <%c>, but only %" G_GSIZE_FORMAT " bytes remain."
+#define no_string_msg \
+        "Expected a string, trying to skip to end of [sub]buffer."
 
     gsize tsize, alen;
 
