@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwygraphcurves.c 7659 2007-03-05 13:52:56Z yeti-dn $
+ *  @(#) $Id: gwygraphcurves.c 9109 2009-03-30 12:28:59Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -388,7 +388,7 @@ render_column(GtkCellLayout *column,
             modes = gwy_graph_curve_type_get_enum();
             s = gwy_enum_to_string(v, modes, -1);
             if (s && *s)
-                g_object_set(renderer, "text", s, NULL);
+                g_object_set(renderer, "text", gwy_sgettext(s), NULL);
         }
         break;
 
