@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyruler.c 8063 2007-05-20 09:07:42Z yeti-dn $
+ *  @(#) $Id: gwyruler.c 9115 2009-03-31 09:21:44Z yeti-dn $
  *  Copyright (C) 2003,2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -449,19 +449,12 @@ gwy_ruler_expose(GtkWidget *widget,
     if (GTK_WIDGET_DRAWABLE(widget)) {
         ruler = GWY_RULER(widget);
 
-        gtk_paint_box(widget->style, widget->window,
+        gtk_paint_box(widget->style, ruler->backing_store,
                       GTK_STATE_NORMAL, GTK_SHADOW_OUT,
                       NULL, widget, "ruler",
                       0, 0,
                       widget->allocation.width, widget->allocation.height);
 
-        gdk_draw_drawable(ruler->backing_store,
-                          ruler->non_gr_exp_gc,
-                          widget->window,
-                          0, 0, 0, 0,
-                          widget->allocation.width,
-                          widget->allocation.height);
-
         gwy_ruler_draw_ticks(ruler);
 
         gdk_draw_drawable(widget->window,
