@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: level.c 8885 2008-12-28 12:17:52Z yeti-dn $
+ *  @(#) $Id: level.c 9635 2009-08-21 09:48:13Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -1375,7 +1375,7 @@ pow_int(gdouble x, guint n)
  * @row: Upper-left row coordinate.
  * @width: Area width (number of columns).
  * @height: Area height (number of rows).
- * @nterms: The number of polynomial terms to take into account (twice the
+ * @nterms: The number of polynomial terms to take into account (half the
  *          number of items in @term_powers).
  * @term_powers: Array of size 2*@nterms describing the terms to fit.  Each
  *               terms is described by a couple of powers (powerx, powery).
@@ -1385,6 +1385,10 @@ pow_int(gdouble x, guint n)
  *
  * Fit a given set of polynomial terms to a rectangular part of a data field.
  *
+ * The polynomial coefficients correspond to normalized coordinates that
+ * are always from the interval [-1,1] where -1 corresponds to the left/topmost
+ * pixel and 1 corresponds to the bottom/rightmost pixel of the area.
+ *
  * Returns: Either @coeffs if it was not %NULL, or a newly allocated array
  *          with coefficients.
  *
@@ -1435,15 +1439,17 @@ gwy_data_field_area_fit_poly(GwyDataField *data_field,
         for (c = 0; c < width; c++) {
             gdouble x = 2*c/(width - 1.0) - 1.0;
             gdouble z = data[(row + r)*xres + (col + c)];
-            gdouble w = mask[(row + r)*xres + (col + c)];
+            gdouble w = 1.0;
 
-            if (exclude)
-                w = 1.0-w;
-
-            if (w <= 0.0)
-                continue;
-            if (w >= 1.0)
-                w = 1.0;
+            if (mask) {
+                w = mask[(row + r)*xres + (col + c)];
+                if (exclude)
+                    w = 1.0-w;
+                if (w <= 0.0)
+                    continue;
+                if (w >= 1.0)
+                    w = 1.0;
+            }
 
             for (i = 0; i < nterms; i++) {
                 p[i] = pow_int(x, term_powers[2*i])
@@ -1479,7 +1485,7 @@ gwy_data_field_area_fit_poly(GwyDataField *data_field,
  *        cause inclusion of corresponding @data_field samples.  The behaviour
  *        for values inside (0.0, 1.0) is undefined (it may be specified
  *        in the future).
- * @nterms: The number of polynomial terms to take into account (twice the
+ * @nterms: The number of polynomial terms to take into account (half the
  *          number of items in @term_powers).
  * @term_powers: Array of size 2*@nterms describing the terms to fit.  Each
  *               terms is described by a couple of powers (powerx, powery).
@@ -1517,7 +1523,7 @@ gwy_data_field_fit_poly(GwyDataField *data_field,
  * @row: Upper-left row coordinate.
  * @width: Area width (number of columns).
  * @height: Area height (number of rows).
- * @nterms: The number of polynomial terms to take into account (twice the
+ * @nterms: The number of polynomial terms to take into account (half the
  *          number of items in @term_powers).
  * @term_powers: Array of size 2*@nterms describing the fitted terms.  Each
  *               terms is described by a couple of powers (powerx, powery).
@@ -1574,7 +1580,7 @@ gwy_data_field_area_subtract_poly(GwyDataField *data_field,
 /**
  * gwy_data_field_subtract_poly:
  * @data_field: A data field.
- * @nterms: The number of polynomial terms to take into account (twice the
+ * @nterms: The number of polynomial terms to take into account (half the
  *          number of items in @term_powers).
  * @term_powers: Array of size 2*@nterms describing the fitter terms.  Each
  *               terms is described by a couple of powers (powerx, powery).
