@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: nanoscope.c 9037 2009-03-07 16:45:28Z yeti-dn $
+ *  @(#) $Id: nanoscope.c 10431 2009-11-14 07:36:16Z yeti-dn $
  *  Copyright (C) 2004-2007 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -29,12 +29,18 @@
  * </mime-type>
  **/
 
+/**
+ * [FILE-MAGIC-USERGUIDE]
+ * Veeco Nanoscope III
+ * .001 .002 etc.
+ * Read
+ **/
+
 #include "config.h"
 #include <errno.h>
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdarg.h>
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwyutils.h>
 #include <libgwyddion/gwymath.h>
@@ -48,10 +54,15 @@
 #define MAGIC_TXT "?*File list\r\n"
 #define MAGIC_SIZE (sizeof(MAGIC_TXT)-1)
 
+#define MAGIC_BIN_PARTIAL "\\*File list"
+#define MAGIC_TXT_PARTIAL "?*File list"
+#define MAGIC_SIZE_PARTIAL (sizeof(MAGIC_TXT_PARTIAL)-1)
+
 typedef enum {
     NANOSCOPE_FILE_TYPE_NONE = 0,
     NANOSCOPE_FILE_TYPE_BIN,
-    NANOSCOPE_FILE_TYPE_TXT
+    NANOSCOPE_FILE_TYPE_TXT,
+    NANOSCOPE_FILE_TYPE_BROKEN
 } NanoscopeFileType;
 
 typedef enum {
@@ -134,7 +145,7 @@ static GwyModuleInfo module_info = {
     N_("Imports Veeco (Digital Instruments) Nanoscope data files, "
        "version 3 or newer."),
     "Yeti <yeti@gwyddion.net>",
-    "0.23",
+    "0.24",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -164,8 +175,8 @@ nanoscope_detect(const GwyFileDetectInfo *fileinfo,
         return 0;
 
     if (fileinfo->buffer_len > MAGIC_SIZE
-        && (memcmp(fileinfo->head, MAGIC_TXT, MAGIC_SIZE) == 0
-            || memcmp(fileinfo->head, MAGIC_BIN, MAGIC_SIZE) == 0))
+        && (!memcmp(fileinfo->head, MAGIC_TXT_PARTIAL, MAGIC_SIZE_PARTIAL)
+            || !memcmp(fileinfo->head, MAGIC_BIN_PARTIAL, MAGIC_SIZE_PARTIAL)))
         score = 100;
 
     return score;
@@ -200,6 +211,9 @@ nanoscope_load(const gchar *filename,
             file_type = NANOSCOPE_FILE_TYPE_TXT;
         else if (!memcmp(buffer, MAGIC_BIN, MAGIC_SIZE))
             file_type = NANOSCOPE_FILE_TYPE_BIN;
+        else if (!memcmp(buffer, MAGIC_TXT_PARTIAL, MAGIC_SIZE_PARTIAL)
+                 || !memcmp(buffer, MAGIC_BIN_PARTIAL, MAGIC_SIZE_PARTIAL))
+          file_type = NANOSCOPE_FILE_TYPE_BROKEN;
     }
     if (!file_type) {
         g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
@@ -208,8 +222,23 @@ nanoscope_load(const gchar *filename,
         g_free(buffer);
         return NULL;
     }
+    if (file_type == NANOSCOPE_FILE_TYPE_BROKEN) {
+        g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
+                    _("File has been damaged by change of line endings, "
+                      "resulting in corruption of the binary part of the file."
+                      "\n\n"
+                      "Typically, this occurs if the file is treated as text "
+                      "when sent by e-mail uncompressed, sent by FTP in ascii "
+                      "mode (use binary), compressed by ‘Send to compressed "
+                      "folder’ in some versions of MS Windows, or any other "
+                      "file transfer that attempts to store text "
+                      "platform-independently."));
+        g_free(buffer);
+        return NULL;
+    }
+
     gwy_debug("File type: %d", file_type);
-    /* as already know file_type, fix the first char for hash reading */
+    /* as we already know file_type, fix the first char for hash reading */
     *buffer = '\\';
 
     p = buffer;
