@@ -1,5 +1,5 @@
 /*
- *  $Id: omicron.c 8916 2008-12-30 12:48:54Z yeti-dn $
+ *  $Id: omicron.c 10195 2009-10-01 23:04:26Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek, Markus Pristovsek
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net,
  *  prissi@gift.physik.tu-berlin.de.
@@ -31,6 +31,13 @@
  * </mime-type>
  **/
 
+/**
+ * [FILE-MAGIC-USERGUIDE]
+ * Omicron SCALA
+ * .par .tf* .tb* .sf* .sb*
+ * Read SPS
+ **/
+
 /* TODO: metadata */
 
 #include "config.h"
@@ -221,7 +228,7 @@ omicron_load(const gchar *filename,
         return NULL;
     }
 
-    memset(&ofile, 0, sizeof(OmicronFile));
+    gwy_clear(&ofile, 1);
     ofile.filename = filename;
     if (!omicron_read_header(text, &ofile, error))
         goto fail;
