@@ -30,6 +30,13 @@
  * </mime-type>
  **/
 
+/**
+ * [FILE-MAGIC-USERGUIDE]
+ * Omicron MATRIX
+ * .mtrx
+ * Read
+ **/
+
 /* Version 0.81, 17.10.2008 */
 #include <stdlib.h>
 #include <string.h>
@@ -177,9 +184,9 @@ static GwyModuleInfo module_info = {
     N_("Omicron MATRIX (param.mtrx & data.mtrx)"),
     "Philipp Rahe <hquerquadrat@gmail.com>",
 #ifdef OSNAVERSION
-    "0.81-Osnabruck",
+    "0.82-Osnabruck",
 #else
-    "0.81",
+    "0.82",
 #endif
     "Philipp Rahe",
     "2008",
@@ -226,7 +233,7 @@ static gchar* matrix_readstring(const guchar** fp,
 
     len = gwy_get_guint32_le(fp);
     if(len == 0) {
-        return "";
+        return g_strdup("");
     }
     if(len > STRING_MAXLENGTH) {
       g_warning("omicronmatrix::matrix_readstring:"
@@ -1545,6 +1552,7 @@ static GwyContainer* matrix_load(const gchar* filename,
     gchar newdelimiter = '_';
 
     // Some default values
+    gwy_clear(&matrixdata, 1);
     matrixdata.zoom = 1.0;
     // TODO: correct error-management
     
