@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: shimadzu.c 9037 2009-03-07 16:45:28Z yeti-dn $
+ *  @(#) $Id: shimadzu.c 10431 2009-11-14 07:36:16Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -28,10 +28,16 @@
  * </mime-type>
  **/
 
+/**
+ * [FILE-MAGIC-USERGUIDE]
+ * Shimadzu
+ * <!--FIXME-->
+ * Read
+ **/
+
 #include "config.h"
 #include <string.h>
 #include <stdlib.h>
-#include <stdarg.h>
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwymath.h>
 #include <libprocess/datafield.h>
