@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: sphere-revolve.c 7717 2007-03-15 14:45:27Z yeti-dn $
+ *  @(#) $Id: sphere-revolve.c 8891 2008-12-28 12:18:50Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -94,7 +94,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Subtracts background by arc or sphere revolution."),
     "Yeti <yeti@gwyddion.net>",
-    "1.4",
+    "1.5",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -252,8 +252,8 @@ sphrev_dialog(Sphrev1DArgs *args)
         = gwy_radio_buttons_create(directions, G_N_ELEMENTS(directions),
                                    G_CALLBACK(direction_changed_cb), args,
                                    args->direction);
-    gwy_radio_buttons_attach_to_table(controls.direction, GTK_TABLE(table),
-                                      4, row);
+    row = gwy_radio_buttons_attach_to_table(controls.direction,
+                                            GTK_TABLE(table), 4, row);
 
     controls.do_extract
         = gtk_check_button_new_with_mnemonic(_("E_xtract background"));
