@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: tip_model.c 7188 2006-12-12 19:23:09Z yeti-dn $
+ *  @(#) $Id: tip_model.c 9017 2009-02-24 09:41:45Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -111,7 +111,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Models SPM tip."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.4",
+    "1.5",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -372,9 +372,8 @@ create_preset_menu(GCallback callback,
         }
     }
 
-    /* XXX: presets currently not translatable? */
     return gwy_enum_combo_box_new(entries, nentries,
-                                  callback, cbdata, current, FALSE);
+                                  callback, cbdata, current, TRUE);
 }
 
 static void
