@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: pygwy.c 8836 2008-12-12 14:23:42Z xhorak $
+ *  @(#) $Id: pygwy.c 9254 2009-06-15 13:26:13Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -317,7 +317,7 @@ pygwy_get_plugin_metadata(const gchar *filename,
     *desc = pygwy_read_val_from_dict(plugin_dict, "plugin_desc", filename);
     *menu_path = pygwy_read_val_from_dict(plugin_dict, "plugin_menu", filename);
     type_str = pygwy_read_val_from_dict(plugin_dict, "plugin_type", filename);
-    gwy_debug("read values: %s %s %s %x %x %x", *desc, *menu_path, type_str, *desc, *menu_path, type_str);
+    gwy_debug("read values: %s %s %s %p %p %p", *desc, *menu_path, type_str, *desc, *menu_path, type_str);
     if (!type_str) {
        g_warning("Undefined plugin type, cannot load.");
        *type = PYGWY_UNDEFINED;
@@ -677,7 +677,7 @@ pygwy_reload_code(PygwyPluginInfo **info)
             (*info)->code = code_obj; // XXX: override info->code without Py_DECREF is ok?
             (*info)->m_time = file_stat.st_mtime;
         } else {
-            g_debug("No changes in '%s' since last run.", (*info)->filename);
+            gwy_debug("No changes in '%s' since last run.", (*info)->filename);
         }
     } else {
         g_warning("Cannot get last modification time for file '%s'",
@@ -940,7 +940,8 @@ pygwy_file_load_run(const gchar *filename,
         goto error;
     PyDict_SetItemString(d, "filename", o);
     cmd = g_strdup_printf("import %s\n"
-                          "result = %s.load(\"test\")\nprint result",
+                          "result = %s.load(filename)\n"
+                          "print result",
                           info->name,
                           info->name);
     pygwy_run_string(cmd, Py_file_input, d, d);
